
/*= Rohde & Schwarz - Signal Generator SME ==================================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __rssme_HEADER
#define __rssme_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#define PI                              3.141592654
#define BYTE_LEN                        8
#define NAME_LEN                        7
#define rssme_NUMB_OF_AVAILABLE_OPTIONS       13

/*****************************************************************************/
/*= Define Instrument Specific Error Codes Here =============================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define rssme_WARN_NUSP_OPTION          (VI_WARNING_INSTR_OFFSET + 0x00L)
#define rssme_ERROR_INSTRUMENT_ERROR    (VI_ERROR_INSTR_OFFSET+0x00L)
#define rssme_ERROR_DM_CONFLICT         (VI_ERROR_INSTR_OFFSET+0x01L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rssme_init (ViRsrc resourceName, ViBoolean IDQuery,
                        ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rssme_applicOutpAmplModul (ViSession instrumentHandle,
                        ViReal64 carrierFrequencyHz,
                        ViReal64 carrierLeveldBm,
                        ViReal64 depth,
                        ViBoolean internalSource,
                        ViReal64 frequencyHz, ViInt16 shape);
ViStatus _VI_FUNC rssme_confCarrFreq (ViSession instrumentHandle,
                        ViReal64 frequencyHz, ViReal64 offsetHz,
                        ViBoolean operatingMode);
ViStatus _VI_FUNC rssme_confCarrLevel (ViSession instrumentHandle, ViReal64 level,
                        ViReal64 offsetdB, ViReal64 levelLimit,
                        ViInt16 unit, ViBoolean operatingMode,
                        ViBoolean attenuator);
ViStatus _VI_FUNC rssme_confALC (ViSession instrumentHandle, ViBoolean ALCState,
                        ViInt16 autoBandwidth, ViBoolean bandwidth);
ViStatus _VI_FUNC rssme_confUserCorr (ViSession instrumentHandle,
                        ViBoolean correctionState, ViInt16 corrList,
                        ViString corrListName,
                        ViReal64 _VI_FAR frequencyHz[],
                        ViReal64 _VI_FAR leveldB[],
                        ViInt32 corrListLength);
ViStatus _VI_FUNC rssme_confAmplModul (ViSession instrumentHandle,
                        ViBoolean AMState, ViInt16 modulationSource,
                        ViReal64 depth, ViBoolean extCoupling,
                        ViBoolean polarity);
ViStatus _VI_FUNC rssme_confFreqModul (ViSession instrumentHandle,
                        ViBoolean FM1State, ViBoolean FM2State,
                        ViReal64 FM1DeviationHz,
                        ViReal64 FM2DeviationHz,
                        ViInt16 FM1ModulationSource,
                        ViInt16 FM2ModulationSource,
                        ViBoolean ext1Coupling,
                        ViBoolean ext2Coupling, ViInt16 preemphasis);
ViStatus _VI_FUNC rssme_confPhasModul (ViSession instrumentHandle,
                        ViBoolean PM1State, ViReal64 PM1Deviation,
                        ViBoolean PM2State, ViReal64 PM2Deviation,
                        ViBoolean unit, ViInt16 PM1ModulationSource,
                        ViInt16 PM2ModulationSource,
                        ViBoolean ext1Coupling,
                        ViBoolean ext2Coupling);
ViStatus _VI_FUNC rssme_confPulsModul (ViSession instrumentHandle,
                        ViBoolean pulseModulationState,
                        ViBoolean polarity,
                        ViBoolean extImpedanceOhm,
                        ViReal64 pulseWidths, ViReal64 pulseDelays,
                        ViReal64 pulsePeriodFreq,
                        ViBoolean pulseParameter,
                        ViBoolean pulseShape,
                        ViBoolean modulationSource);
ViStatus _VI_FUNC rssme_confStereoModul (ViSession instrumentHandle,
                        ViBoolean stereoModulationState,
                        ViReal64 deviationHz,
                        ViReal64 audioFrequencyHz,
                        ViInt16 preemphasis, ViBoolean pilotState,
                        ViReal64 pilotDeviationHz,
                        ViReal64 pilotPhase, ViBoolean unit,
                        ViInt16 mode, ViReal64 ARIDeviationHz,
                        ViInt16 ARIBK, ViInt16 ARIIdentification,
                        ViBoolean stereoOutput);
ViStatus _VI_FUNC rssme_confVORModul (ViSession instrumentHandle, ViInt16 VORMode,
                        ViReal64 bearingAngle, ViBoolean unit,
                        ViBoolean direction,
                        ViReal64 VARREFFrequencyHz, ViReal64 VARDepth,
                        ViReal64 subcarrFrequencyHz,
                        ViReal64 subcarrDepth, ViBoolean comIdState,
                        ViReal64 comIdFrequencyHz,
                        ViReal64 comIdDepth, ViReal64 refDeviationHz,
                        ViBoolean signalSource);
ViStatus _VI_FUNC rssme_confILSGSModul (ViSession instrumentHandle,
                        ViBoolean ILSGSState, ViBoolean direction,
                        ViReal64 upperFrequencyHz,
                        ViReal64 lowerFrequencyHz,
                        ViReal64 upLowPhase, ViBoolean unit,
                        ViInt16 ILSSignal, ViInt16 DDM,
                        ViReal64 DDMValue, ViBoolean comIdState,
                        ViReal64 comIdFrequencyHz,
                        ViReal64 comIdDepth, ViBoolean signalSource,
                        ViReal64 sumofDepth);
ViStatus _VI_FUNC rssme_confILSLocModul (ViSession instrumentHandle,
                        ViBoolean ILSLocState, ViBoolean direction,
                        ViReal64 leftFrequencyHz,
                        ViReal64 rightFrequencyHz,
                        ViReal64 leftRightPhase, ViBoolean unit,
                        ViInt16 ILSSignal, ViInt16 DDM,
                        ViReal64 DDMValue, ViBoolean comIdState,
                        ViReal64 comIdFrequencyHz,
                        ViReal64 comIdDepth,
                        ViBoolean signalSource,
                        ViReal64 sumofDepth);
ViStatus _VI_FUNC rssme_confMBeModul (ViSession instrumentHandle,
                        ViBoolean MBeState, ViInt16 frequency,
                        ViReal64 depth, ViBoolean comIdState,
                        ViReal64 comIdFrequencyHz,
                        ViReal64 comIdDepth);
ViStatus _VI_FUNC rssme_confDMGMSK (ViSession instrumentHandle, ViInt16 source,
                        ViInt16 standard, ViInt16 bitratekbs,
                        ViInt16 filter, ViBoolean polarity,
                        ViBoolean diffEncoder);
ViStatus _VI_FUNC rssme_confDMGFSK (ViSession instrumentHandle, ViInt16 source,
                        ViInt16 standard, ViReal64 bitRatekbs,
                        ViInt16 filter, ViBoolean polarity,
                        ViInt16 deviationkHz);
ViStatus _VI_FUNC rssme_confDMQPSK (ViSession instrumentHandle, ViInt16 source,
                        ViInt16 standard, ViReal64 bitratekbs,
                        ViInt16 filter, ViBoolean polarity,
                        ViInt16 type, ViInt16 coding);
ViStatus _VI_FUNC rssme_confDMFSK (ViSession instrumentHandle, ViInt16 source,
                        ViInt16 standard, ViReal64 bitratekbs,
                        ViInt16 filter, ViBoolean polarity,
                        ViReal64 deviationkHz);
ViStatus _VI_FUNC rssme_confDMFSK4 (ViSession instrumentHandle, ViInt16 source,
                        ViInt16 standard, ViReal64 bitratekbs,
                        ViInt16 filter, ViBoolean polarity,
                        ViReal64 deviationkHz, ViInt16 coding);
ViStatus _VI_FUNC rssme_confDMFFSK (ViSession instrumentHandle, ViInt16 source,
                        ViInt16 standard, ViReal64 bitratekbs,
                        ViInt16 deviationkHz);
ViStatus _VI_FUNC rssme_confDMSetup (ViSession instrumentHandle,
                        ViInt16 modulationType, ViInt16 outputMode);
ViStatus _VI_FUNC rssme_confDMERMESChanBitBatch (ViSession instrumentHandle,
                        ViInt16 channel,
                        ViString messages,
                        ViInt32 errorBitMask,
                        ViString errorBatchPosition,
                        ViInt32 errorWordPosition);
ViStatus _VI_FUNC rssme_confDMERMESNetSyst (ViSession instrumentHandle,
                        ViBoolean extTrafficIndicator,
                        ViBoolean borderAreaIndicator,
                        ViInt32 freqSubsetIndicator,
                        ViInt32 day, ViInt32 hour,
                        ViInt32 minute, ViInt32 zoneCountryCode,
                        ViInt32 operatorCode,
                        ViInt32 pagingArea);
ViStatus _VI_FUNC rssme_confDMERMESMessage (ViSession instrumentHandle,
                        ViInt32 initialAddress,
                        ViInt16 messageType, ViInt16 toneNumber,
                        ViString numericMessage,
                        ViInt16 alphaNumMessageName,
                        ViString alphaNumMessage);
ViStatus _VI_FUNC rssme_confDMFLEXSystBit (ViSession instrumentHandle,
                        ViInt16 modulation,
                        ViReal64 deviationkHz,
                        ViInt32 systemCollapse,
                        ViInt32 localChannelID, ViInt32 timeZone,
                        ViInt32 year, ViInt32 month, ViInt32 day,
                        ViInt32 hour, ViInt32 minute,
                        ViReal64 errorBitMask,
                        ViInt32 errorWordPosition);
ViStatus _VI_FUNC rssme_confDMFLEXSelMessage (ViSession instrumentHandle,
                        ViString capcode,
                        ViInt16 phase, ViInt32 toneNumber,
                        ViBoolean autoAdjustPhase,
                        ViBoolean autoAdjustFrame,
                        ViInt32 repeats,
                        ViBoolean messageNumbering,
                        ViBoolean mailDropFlag,
                        ViInt16 messageType,
                        ViString numSNumMessage,
                        ViInt16 alphaNumMessageName,
                        ViInt16 binaryMessageName);
ViStatus _VI_FUNC rssme_confDMFLEXEditMessage (ViSession instrumentHandle,
                        ViInt16 edit,
                        ViInt16 alphaNumMsgName,
                        ViString alphaNumMessage,
                        ViInt32 startCycle,
                        ViString frame,
                        ViInt16 binMessageName,
                        ViString binaryMessage,
                        ViInt16 binMessageType,
                        ViInt32 binBlockingLength);
ViStatus _VI_FUNC rssme_confDMPOCSAGSyst (ViSession instrumentHandle,
                        ViBoolean modulation,
                        ViInt16 deviationkHz, ViInt16 bitratebs);
ViStatus _VI_FUNC rssme_confDMPOCSAGMessage (ViSession instrumentHandle,
                        ViInt32 initialAddress,
                        ViInt16 messageType, ViInt16 toneType,
                        ViString numericMessage,
                        ViInt16 alphaNumMessageName,
                        ViString alphaNumMessage,
                        ViBoolean syncWord, ViInt32 timeSlices);
ViStatus _VI_FUNC rssme_confDMEditCatalog (ViSession instrumentHandle,
                        ViInt16 action,
                        ViChar _VI_FAR oldCatalogContent[],
                        ViPInt32 oldOccupiedMemory,
                        ViPInt32 oldVacantMemory,
                        ViString dataListName,
                        ViChar _VI_FAR newCatalogContent[],
                        ViPInt32 newOccupiedMemory,
                        ViPInt32 newVacantMemory);
ViStatus _VI_FUNC rssme_confDMCreateDataLst (ViSession instrumentHandle,
                        ViString dataListName,
                        ViInt32 listLength,
                        ViString data,
                        ViString attenuator,
                        ViString burst);
ViStatus _VI_FUNC rssme_confDMUpldList (ViSession instrumentHandle,
                        ViString fileName,
                        ViString dataListName,
                        ViInt16 dataType, ViInt32 listLength);
ViStatus _VI_FUNC rssme_confDMActiveLst (ViSession instrumentHandle,
                        ViString dataListName,
                        ViInt16 PRBS, ViBoolean clockEdge,
                        ViBoolean clockSource, ViBoolean clockMode,
                        ViInt16 attenuationMode,
                        ViReal64 attenuationLeveldB);
ViStatus _VI_FUNC rssme_confDMUpldXMem (ViSession instrumentHandle,
                        ViString fileName,
                        ViBoolean memoryMode, ViInt16 dataType,
                        ViInt32 startAddress, ViInt32 length);
ViStatus _VI_FUNC rssme_confDMRecordXMem (ViSession instrumentHandle,
                        ViInt32 startAddress, ViInt32 length,
                        ViBoolean memoryMode,
                        ViBoolean extTrigger,
                        ViBoolean triggerSlope);
ViStatus _VI_FUNC rssme_confFreqSweep (ViSession instrumentHandle,
                        ViInt16 sweepMode, ViInt16 freqInputMode,
                        ViReal64 startFrequencyHz,
                        ViReal64 stopFrequencyHz,
                        ViReal64 centerFrequencyHz,
                        ViReal64 frequencySpanHz,
                        ViReal64 dwellTimes, ViReal64 stepWidth,
                        ViBoolean spacing);
ViStatus _VI_FUNC rssme_confFreqSweepMrks (ViSession instrumentHandle,
                        ViReal64 m1FrequencyHz,
                        ViReal64 m2FrequencyHz,
                        ViReal64 m3FrequencyHz,
                        ViBoolean m1State, ViBoolean m2State,
                        ViBoolean m3State, ViBoolean amplitudeM1,
                        ViBoolean amplitudeM2,
                        ViBoolean amplitudeM3,
                        ViBoolean polarity);
ViStatus _VI_FUNC rssme_confLevelSweep (ViSession instrumentHandle,
                        ViInt16 sweepMode, ViReal64 startLevel,
                        ViReal64 stopLevel, ViInt16 unit,
                        ViReal64 dwellTimes, ViReal64 stepWidthdB);
ViStatus _VI_FUNC rssme_confLevelSweepMrks (ViSession instrumentHandle,
                        ViReal64 m1Level, ViReal64 m2Level,
                        ViReal64 m3Level, ViBoolean m1State,
                        ViBoolean m2State, ViBoolean m3State,
                        ViBoolean polarity);
ViStatus _VI_FUNC rssme_confLFGen (ViSession instrumentHandle, ViBoolean source,
                        ViReal64 voltageV, ViReal64 LFGen1FrequencyHz,
                        ViInt16 LFGen1Shape, ViReal64 LFGen2FrequencyHz,
                        ViInt16 LFGen2Shape, ViBoolean LFGen2Mode);
ViStatus _VI_FUNC rssme_confLFSweep (ViSession instrumentHandle, ViInt16 sweepMode,
                        ViReal64 startFrequencyHz,
                        ViReal64 stopFrequencyHz, ViBoolean spacing,
                        ViReal64 stepWidth, ViReal64 dwellTimes);
ViStatus _VI_FUNC rssme_confLFSweepMrks (ViSession instrumentHandle,
                        ViReal64 m1FrequencyHz,
                        ViReal64 m2FrequencyHz,
                        ViReal64 m3FrequencyHz, ViBoolean m1State,
                        ViBoolean m2State, ViBoolean m3State,
                        ViBoolean polarity);
ViStatus _VI_FUNC rssme_confSaveRecallSetup (ViSession instrumentHandle,
                        ViInt32 setupNumber,
                        ViBoolean setupMode,
                        ViBoolean recallFrequency,
                        ViBoolean recallLevel);
ViStatus _VI_FUNC rssme_confEditCatalog (ViSession instrumentHandle, ViInt16 action,
                        ViChar _VI_FAR oldCatalogContent[],
                        ViPInt32 oldOccupiedMemory,
                        ViPInt32 oldVacantMemory,
                        ViString name,
                        ViChar _VI_FAR newCatalogContent[],
                        ViPInt32 newOccupiedMemory,
                        ViPInt32 newVacantMemory, ViBoolean setup);
ViStatus _VI_FUNC rssme_confCreateLst (ViSession instrumentHandle,
                        ViString listName,
                        ViInt32 listLength,
                        ViReal64 _VI_FAR frequency[],
                        ViReal64 _VI_FAR level[],
                        ViReal64 dwellTimes);
ViStatus _VI_FUNC rssme_confCreateMemSeq (ViSession instrumentHandle,
                        ViString sequenceName,
                        ViInt32 sequenceLength,
                        ViInt32 _VI_FAR setupList[],
                        ViReal64 _VI_FAR dwellLists[]);
ViStatus _VI_FUNC rssme_confSelLstSeq (ViSession instrumentHandle,
                        ViInt16 setupMode, ViBoolean stepMode,
                        ViString seqListName);
ViStatus _VI_FUNC rssme_confTrigger (ViSession instrumentHandle,
                        ViInt16 triggerType, ViInt16 triggerSource,
                        ViInt16 extTriggerSlope);
ViStatus _VI_FUNC rssme_confOPTLst (ViSession instrumentHandle,
                        ViChar _VI_FAR optionsList[],
                        ViChar _VI_FAR instrumentVersion[]);
ViStatus _VI_FUNC rssme_confRefOscillator (ViSession instrumentHandle,
                        ViBoolean referenceSource,
                        ViBoolean phaseAdjustment,
                        ViBoolean unit, ViReal64 deltaPhase,
                        ViBoolean frequencyAdjustment,
                        ViInt32 frequencyCorrection);
ViStatus _VI_FUNC rssme_confOuts (ViSession instrumentHandle,
                        ViBoolean blankPolarity, ViBoolean blankTime,
                        ViBoolean protection, ViPInt32 tripped);
ViStatus _VI_FUNC rssme_confBeep (ViSession instrumentHandle, ViBoolean beeperState);
ViStatus _VI_FUNC rssme_qRFfrequency (ViSession instrumentHandle,
                                      ViReal64 RFFrequencyHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qRFlevel (ViSession instrumentHandle, ViReal64 RFLeveldBm,
                                  ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qRFlevOffset (ViSession instrumentHandle,
                                      ViReal64 levelOffsetdB, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qRFstartStopFreq (ViSession instrumentHandle,
                                          ViReal64 startFreqHz, ViReal64 stopFreqHz,
                                          ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qRFcenterSpanFreq (ViSession instrumentHandle,
                                           ViReal64 centerFreqHz,
                                           ViReal64 freqSpanHz,
                                           ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qRFsweepStep (ViSession instrumentHandle,
                                      ViReal64 stepWidthHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qLFfreq (ViSession instrumentHandle, ViBoolean LFGenerator,
                                 ViReal64 frequencyHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qLFvolt (ViSession instrumentHandle, ViReal64 voltageV,
                                 ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qAMmodDep (ViSession instrumentHandle,
                                   ViReal64 modulationDepthPerc,
                                   ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qFMdev (ViSession instrumentHandle, ViBoolean modulator,
                                ViReal64 freqDeviationHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qPHMdev (ViSession instrumentHandle, ViBoolean modulator,
                                 ViReal64 phaseDeviationRad, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qPulsModDelay (ViSession instrumentHandle,
                                       ViReal64 pulseDelays, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qPulsModPeriod (ViSession instrumentHandle,
                                        ViReal64 pulsePeriods, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qPulsModWidth (ViSession instrumentHandle,
                                       ViReal64 pulseWidths, ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qStereoModDev (ViSession instrSession, ViReal64 deviation,
                    ViBoolean checkRange);
ViStatus _VI_FUNC rssme_qStereoModAudioFreq (ViSession instrSession, ViReal64 audioFreq,
                    ViBoolean checkRange);
ViStatus _VI_FUNC rssme_outState (ViSession instrumentHandle, ViBoolean RFOutput,
                        ViBoolean LFOutput);
ViStatus _VI_FUNC rssme_sendTrig (ViSession instrumentHandle, ViInt16 triggerType);
ViStatus _VI_FUNC rssme_abort (ViSession instrumentHandle, ViInt16 abort);
ViStatus _VI_FUNC rssme_recordXMem (ViSession instrumentHandle);
ViStatus _VI_FUNC rssme_abortXMem (ViSession instrumentHandle);
ViStatus _VI_FUNC rssme_recalculDM (ViSession instrumentHandle,
                        ViInt16 modulationType);
ViStatus _VI_FUNC rssme_step (ViSession instrumentHandle, ViBoolean stepMode,
                        ViBoolean direction, ViInt16 parameter,
                        ViReal64 stepSize);
ViStatus _VI_FUNC rssme_operationComplete (ViSession instrumentHandle,
                        ViInt32 maxTimeouts);
ViStatus _VI_FUNC rssme_writeInstrData (ViSession instrumentHandle,
                        ViString writeBuffer);
ViStatus _VI_FUNC rssme_readInstrData (ViSession instrumentHandle,
                        ViInt16 numberBytesToRead,
                        ViChar _VI_FAR readBuffer[],
                        ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssme_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssme_self_test (ViSession instrSession, ViPInt16 result,
                                   ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssme_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssme_error_message (ViSession instrumentHandle,
                        ViStatus errorCode,
                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssme_revision_query (ViSession instrumentHandle,
                        ViChar _VI_FAR instrumentDriverRevision[],
                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssme_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
